@@ -172,6 +172,26 @@ def _writeModuleParamField(module, NewParamValueDictionary, hubName):
         data = (parmString, module)
         db.query_rowcount(sql, data)
 
+def _writeTempalteParamField(template, NewParamValueDictionary, hubName):
+        """
+        Take a dictionary, transform it to properly formatted params string for Joomla, and 
+        update the params field of the jos_template_styles table for the specified template
+        """
+        # database config
+        dbPW = getWebConfigDBPassword(hubName)
+        dbUserName = getWebConfigDBUsername(hubName)
+        dbName = getWebConfigDBName(hubName)
+        db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
+
+        if hubzero.utilities.misc.JOOMLA_25:
+                parmString = json.dumps(NewParamValueDictionary)
+                sql = "UPDATE `jos_template_styles` SET `params`=%s WHERE `template`=%s"
+        else:
+		raise Exception
+
+        data = (parmString, tempalte)
+        db.query_rowcount(sql, data)
+
 
 
 def _buildDictionary(componentOption, hubName):
@@ -301,6 +321,45 @@ def _buildModuleDictionary(module, hubName):
 
         return parmsDict
 
+def _buildTemplateDictionary(template, hubName):
+        """
+        Put the parameter string of the database into a dictionary
+        String follows the format:
+        
+        param1=value1
+        param2=value2
+        param3=value3
+        
+        """
+        # database config
+        dbPW = getWebConfigDBPassword(hubName)
+        dbUserName = getWebConfigDBUsername(hubName)
+        dbName = getWebConfigDBName(hubName)
+        db =  hubzero.data.db.MySQLConnection("localhost", dbName, dbUserName, dbPW)
+
+        # look up parm string and parse it on newline, for each line, parse it further based on *first* '='
+        sql = "SELECT `params` from jos_template_styles WHERE template=%s"
+
+        data = (module)
+        paramsString = db.query_selectscalar(sql,template)
+
+        if hubzero.utilities.misc.JOOMLA_25 and paramsString.startswith('{'):
+                try:
+                        parmsDict = json.loads(paramsString)
+                        return parmsDict
+                except:
+                        pass
+
+        parmsDict = {}
+
+        if paramsString:
+                parms = paramsString.split("\n")
+                for parmline in parms:
+                        if parmline: # in case of any blank lines in the params field
+                                n,v = parmline.split("=", 1)
+                                parmsDict[n] = v
+
+        return parmsDict
 
 def getComponentParam(componentOption, parameterName, hubName = ""):
 	"""
@@ -375,6 +434,22 @@ def addModuleParam(module, parameterName, parameterValue, allowOverwrite=True, h
 
 	_writeModuleParamField(module, paramDict, hubName)	
 
+def addTemplateParam(template, parameterName, parameterValue, allowOverwrite=True, hubName = ""):
+        """
+        Add value to the param string in the jos_components table for the specified component.
+        """
+        paramDict = _buildTemplateDictionary(template,hubName)
+
+        if allowOverwrite:
+                paramDict[parameterName] = parameterValue
+        else:
+                if paramDict.has_key(parameterName):
+                        raise Exception("ERROR: addModuleParam called for existing parameter with allowOverwrite = false")
+                else:
+                        paramDict[parameterName] = parameterValue
+
+        _writeTemplateParamField(module, paramDict, hubName)
+
 	
 def delComponentParam(componentOption, parameterName, hubName = ""):
 	"""
